import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'blue');

  // Single Stem
  svg.append('rect')
    .attr('x', width / 2 - 3) // Center the stem
    .attr('y', height / 2)
    .attr('width', 10)
    .attr('height', 100)
    .attr('fill', 'green');

  // Flower Configuration
  const flowerX = width / 2;
  const flowerY = height / 2 - 75;
  const petalSize = 40; // Larger petal size
  const petalCount = 12; // More petals for a fuller look
  const petalColor = 'purple'; // Petal color
  const growthDuration = 2000;

  // Petals
  for (let j = 0; j < petalCount; j++) {
    const angle = Math.PI * 2 / petalCount * j;
    const petalX = flowerX + Math.cos(angle) * petalSize * 1.5; // Increase radius for larger flower
    const petalY = flowerY + Math.sin(angle) * petalSize * 1.5;

    svg.append('circle')
      .attr('cx', petalX)
      .attr('cy', petalY)
      .attr('r', 0)
      .attr('fill', petalColor)
      .transition()
      .duration(growthDuration)
      .attr('r', petalSize / 2);
  }

  // Center of the Flower
  svg.append('circle')
    .attr('cx', flowerX)
    .attr('cy', flowerY)
    .attr('r', 0)
    .attr('fill', 'yellow')
    .transition()
    .duration(growthDuration)
    .attr('r', petalSize / 2+10);
  
  // Leaves
  const leafWidth = 20;
  const leafHeight = 50;
  // Left Leaf
  svg.append('path')
    .attr('d', `M${width / 2 - 5},${height / 2 + 95} 
                q${-leafWidth},${-leafHeight / 2} ${-leafWidth / 2},${-leafHeight}
                q${leafWidth / 4},${leafHeight / 3} ${leafWidth / 2},${leafHeight}`)
    .attr('fill', 'green');

  // Right Leaf
  svg.append('path')
    .attr('d', `M${width / 2 + 5},${height / 2 + 75} 
                q${leafWidth},${-leafHeight / 2} ${leafWidth / 2},${-leafHeight}
                q${-leafWidth / 4},${leafHeight / 3} ${-leafWidth / 2},${leafHeight}`)
    .attr('fill', 'green');
  // Vase
  // Vase Bottom (Ellipse)
  svg.append('ellipse')
    .attr('cx', width / 2)
    .attr('cy', height - 10)
    .attr('rx', 60)
    .attr('ry', 50)
    .attr('fill', 'saddlebrown');

  // Vase Body (Rectangle)
  svg.append('rect')
    .attr('x', width / 2 - 20)
    .attr('y', height / 2 + 80)
    .attr('width', 40)
    .attr('height', 120)
    .attr('fill', 'saddlebrown');
};
